import type { OnModuleInit } from '@nestjs/common'
import { ConnectedSocket, MessageBody, SubscribeMessage, WebSocketGateway, WebSocketServer } from '@nestjs/websockets'
import type { Server, Socket } from 'socket.io'

@WebSocketGateway({ cors: { origin: '*' } })
export class MyGateway implements OnModuleInit {
  @WebSocketServer()
  server: Server

  onModuleInit(): void {
    this.server.on('connection', (socket) => {
      console.log(socket.id)
      console.log('Connected')
    })
  }

  @SubscribeMessage('newMessage')
  onNewMessage(@MessageBody() data: string, @ConnectedSocket() client: Socket): void {
    console.log(data, client)
    this.server.emit('onMessage', {
      msg: 'New Message',
      content: data,
      client
    })
  }
}
